==> com.liferay.frontend.editor.tinymce.web-3.0.20.jar: META-INF/resources/tiny_mce/langs/de.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('de', {
	Cut: 'Ausschneiden',
	'Heading 5': '\u00dcberschrift 5',
	'Header 2': '\u00dcberschrift 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Ihr Browser unterst\u00fctzt leider keinen direkten Zugriff auf die Zwischenablage. Bitte benutzen Sie die Strg + X / C / V Tastenkombinationen.',
	'Heading 4': '\u00dcberschrift 4',
	Div: 'Textblock',
	'Heading 2': '\u00dcberschrift 2',
	Paste: 'Einf\u00fcgen',
	Close: 'Schlie\u00dfen',
	'Font Family': 'Schriftart',
	Pre: 'Vorformatierter Text',
	'Align right': 'Rechtsb\u00fcndig ausrichten',
	'New document': 'Neues Dokument',
	Blockquote: 'Zitat',
	'Numbered list': 'Nummerierte Liste',
	'Heading 1': '\u00dcberschrift 1',
	Headings: '\u00dcberschriften',
	'Increase indent': 'Einzug vergr\u00f6\u00dfern',
	Formats: 'Formate',
	Headers: '\u00dcberschriften',
	'Select all': 'Alles ausw\u00e4hlen',
	'Header 3': '\u00dcberschrift 3',
	Blocks: 'Absatzformate',
	Undo: 'R\u00fcckg\u00e4ngig',
	Strikethrough: 'Durchgestrichen',
	'Bullet list': 'Aufz\u00e4hlung',
	'Header 1': '\u00dcberschrift 1',
	Superscript: 'Hochgestellt',
	'Clear formatting': 'Formatierung entfernen',
	'Font Sizes': 'Schriftgr\u00f6\u00dfe',
	Subscript: 'Tiefgestellt',
	'Header 6': '\u00dcberschrift 6',
	Redo: 'Wiederholen',
	Paragraph: 'Absatz',
	Ok: 'Ok',
	Bold: 'Fett',
	Code: 'Quelltext',
	Italic: 'Kursiv',
	'Align center': 'Zentriert ausrichten',
	'Header 5': '\u00dcberschrift 5',
	'Heading 6': '\u00dcberschrift 6',
	'Heading 3': '\u00dcberschrift 3',
	'Decrease indent': 'Einzug verkleinern',
	'Header 4': '\u00dcberschrift 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Einf\u00fcgen ist nun im einfachen Textmodus. Inhalte werden ab jetzt als unformatierter Text eingef\u00fcgt, bis Sie diese Einstellung wieder ausschalten!',
	Underline: 'Unterstrichen',
	Cancel: 'Abbrechen',
	Justify: 'Blocksatz',
	Inline: 'Zeichenformate',
	Copy: 'Kopieren',
	'Align left': 'Linksb\u00fcndig ausrichten',
	'Visual aids': 'Visuelle Hilfen',
	'Lower Greek': 'Griechische Kleinbuchstaben',
	Square: 'Quadrat',
	Default: 'Standard',
	'Lower Alpha': 'Kleinbuchstaben',
	Circle: 'Kreis',
	Disc: 'Punkt',
	'Upper Alpha': 'Gro\u00dfbuchstaben',
	'Upper Roman': 'R\u00f6mische Zahlen (Gro\u00dfbuchstaben)',
	'Lower Roman': 'R\u00f6mische Zahlen (Kleinbuchstaben)',
	Name: 'Name',
	Anchor: 'Textmarke',
	'You have unsaved changes are you sure you want to navigate away?':
		'Die \u00c4nderungen wurden noch nicht gespeichert, sind Sie sicher, dass Sie diese Seite verlassen wollen?',
	'Restore last draft': 'Letzten Entwurf wiederherstellen',
	'Special character': 'Sonderzeichen',
	'Source code': 'Quelltext',
	Color: 'Farbe',
	'Right to left': 'Von rechts nach links',
	'Left to right': 'Von links nach rechts',
	Emoticons: 'Emoticons',
	Robots: 'Robots',
	'Document properties': 'Dokumenteigenschaften',
	Title: 'Titel',
	Keywords: 'Sch\u00fcsselw\u00f6rter',
	Encoding: 'Zeichenkodierung',
	Description: 'Beschreibung',
	Author: 'Verfasser',
	Fullscreen: 'Vollbild',
	'Horizontal line': 'Horizontale Linie',
	'Horizontal space': 'Horizontaler Abstand',
	'Insert/edit image': 'Bild einf\u00fcgen/bearbeiten',
	General: 'Allgemein',
	Advanced: 'Erweitert',
	Source: 'Quelle',
	Border: 'Rahmen',
	'Constrain proportions': 'Seitenverh\u00e4ltnis beibehalten',
	'Vertical space': 'Vertikaler Abstand',
	'Image description': 'Bildbeschreibung',
	Style: 'Stil',
	Dimensions: 'Abmessungen',
	'Insert image': 'Bild einf\u00fcgen',
	'Insert date/time': 'Datum/Uhrzeit einf\u00fcgen ',
	'Remove link': 'Link entfernen',
	Url: 'URL',
	'Text to display': 'Anzuzeigender Text',
	Anchors: 'Textmarken',
	'Insert link': 'Link einf\u00fcgen',
	'New window': 'Neues Fenster',
	None: 'Keine',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'Diese Adresse scheint ein externer Link zu sein. M\u00f6chten Sie das dazu ben\u00f6tigte "http://" voranstellen?',
	Target: 'Ziel',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'Diese Adresse scheint eine E-Mail-Adresse zu sein. M\u00f6chten Sie das dazu ben\u00f6tigte "mailto:" voranstellen?',
	'Insert/edit link': 'Link einf\u00fcgen/bearbeiten',
	'Insert/edit video': 'Video einf\u00fcgen/bearbeiten',
	Poster: 'Poster',
	'Alternative source': 'Alternative Quelle',
	'Paste your embed code below:':
		'F\u00fcgen Sie Ihren Einbettungscode hier ein:',
	'Insert video': 'Video einf\u00fcgen',
	Embed: 'Einbetten',
	'Nonbreaking space': 'Gesch\u00fctztes Leerzeichen',
	'Page break': 'Seitenumbruch',
	'Paste as text': 'Als Text einf\u00fcgen',
	Preview: 'Vorschau',
	Print: 'Drucken',
	Save: 'Speichern',
	'Could not find the specified string.':
		'Die Zeichenfolge wurde nicht gefunden.',
	Replace: 'Ersetzen',
	Next: 'Weiter',
	'Whole words': 'Nur ganze W\u00f6rter',
	'Find and replace': 'Suchen und ersetzen',
	'Replace with': 'Ersetzen durch',
	Find: 'Suchen',
	'Replace all': 'Alles ersetzen',
	'Match case': 'Gro\u00df-/Kleinschreibung beachten',
	Prev: 'Zur\u00fcck',
	Spellcheck: 'Rechtschreibpr\u00fcfung',
	Finish: 'Ende',
	'Ignore all': 'Alles Ignorieren',
	Ignore: 'Ignorieren',
	'Add to Dictionary': 'Zum W\u00f6rterbuch hinzuf\u00fcgen',
	'Insert row before': 'Neue Zeile davor einf\u00fcgen ',
	Rows: 'Zeilen',
	Height: 'H\u00f6he',
	'Paste row after': 'Zeile danach einf\u00fcgen',
	Alignment: 'Ausrichtung',
	'Border color': 'Rahmenfarbe',
	'Column group': 'Spaltengruppe',
	Row: 'Zeile',
	'Insert column before': 'Neue Spalte davor einf\u00fcgen',
	'Split cell': 'Zelle aufteilen',
	'Cell padding': 'Zelleninnenabstand',
	'Cell spacing': 'Zellenabstand',
	'Row type': 'Zeilentyp',
	'Insert table': 'Tabelle einf\u00fcgen',
	Body: 'Inhalt',
	Caption: 'Beschriftung',
	Footer: 'Fu\u00dfzeile',
	'Delete row': 'Zeile l\u00f6schen',
	'Paste row before': 'Zeile davor einf\u00fcgen',
	Scope: 'G\u00fcltigkeitsbereich',
	'Delete table': 'Tabelle l\u00f6schen',
	'H Align': 'Horizontale Ausrichtung',
	Top: 'Oben',
	'Header cell': 'Kopfzelle',
	Column: 'Spalte',
	'Row group': 'Zeilengruppe',
	Cell: 'Zelle',
	Middle: 'Mitte',
	'Cell type': 'Zellentyp',
	'Copy row': 'Zeile kopieren',
	'Row properties': 'Zeileneigenschaften',
	'Table properties': 'Tabelleneigenschaften',
	Bottom: 'Unten',
	'V Align': 'Vertikale Ausrichtung',
	Header: 'Kopfzeile',
	Right: 'Rechtsb\u00fcndig',
	'Insert column after': 'Neue Spalte danach einf\u00fcgen',
	Cols: 'Spalten',
	'Insert row after': 'Neue Zeile danach einf\u00fcgen',
	Width: 'Breite',
	'Cell properties': 'Zelleneigenschaften',
	Left: 'Linksb\u00fcndig',
	'Cut row': 'Zeile ausschneiden',
	'Delete column': 'Spalte l\u00f6schen',
	Center: 'Zentriert',
	'Merge cells': 'Zellen verbinden',
	'Insert template': 'Vorlage einf\u00fcgen ',
	Templates: 'Vorlagen',
	'Background color': 'Hintergrundfarbe',
	'Custom...': 'Benutzerdefiniert...',
	'Custom color': 'Benutzerdefinierte Farbe',
	'No color': 'Keine Farbe',
	'Text color': 'Textfarbe',
	'Show blocks': ' Bl\u00f6cke anzeigen',
	'Show invisible characters': 'Unsichtbare Zeichen anzeigen',
	'Words: {0}': 'W\u00f6rter: {0}',
	Insert: 'Einf\u00fcgen',
	File: 'Datei',
	Edit: 'Bearbeiten',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Rich-Text- Area. Dr\u00fccken Sie ALT-F9 f\u00fcr das Men\u00fc. Dr\u00fccken Sie ALT-F10 f\u00fcr Symbolleiste. Dr\u00fccken Sie ALT-0 f\u00fcr Hilfe',
	Tools: 'Werkzeuge',
	View: 'Ansicht',
	Table: 'Tabelle',
	Format: 'Format'
});

==> com.liferay.frontend.editor.tinymce.web-5.0.15.jar: META-INF/resources/tiny_mce/langs/de.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('de', {
	'Cut': 'Ausschneiden',
	'Heading 5': '\u00dcberschrift 5',
	'Header 2': '\u00dcberschrift 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Ihr Browser unterst\u00fctzt leider keinen direkten Zugriff auf die Zwischenablage. Bitte benutzen Sie die Strg + X / C / V Tastenkombinationen.',
	'Heading 4': '\u00dcberschrift 4',
	'Div': 'Textblock',
	'Heading 2': '\u00dcberschrift 2',
	'Paste': 'Einf\u00fcgen',
	'Close': 'Schlie\u00dfen',
	'Font Family': 'Schriftart',
	'Pre': 'Vorformatierter Text',
	'Align right': 'Rechtsb\u00fcndig ausrichten',
	'New document': 'Neues Dokument',
	'Blockquote': 'Zitat',
	'Numbered list': 'Nummerierte Liste',
	'Heading 1': '\u00dcberschrift 1',
	'Headings': '\u00dcberschriften',
	'Increase indent': 'Einzug vergr\u00f6\u00dfern',
	'Formats': 'Formate',
	'Headers': '\u00dcberschriften',
	'Select all': 'Alles ausw\u00e4hlen',
	'Header 3': '\u00dcberschrift 3',
	'Blocks': 'Absatzformate',
	'Undo': 'R\u00fcckg\u00e4ngig',
	'Strikethrough': 'Durchgestrichen',
	'Bullet list': 'Aufz\u00e4hlung',
	'Header 1': '\u00dcberschrift 1',
	'Superscript': 'Hochgestellt',
	'Clear formatting': 'Formatierung entfernen',
	'Font Sizes': 'Schriftgr\u00f6\u00dfe',
	'Subscript': 'Tiefgestellt',
	'Header 6': '\u00dcberschrift 6',
	'Redo': 'Wiederholen',
	'Paragraph': 'Absatz',
	'Ok': 'Ok',
	'Bold': 'Fett',
	'Code': 'Quelltext',
	'Italic': 'Kursiv',
	'Align center': 'Zentriert ausrichten',
	'Header 5': '\u00dcberschrift 5',
	'Heading 6': '\u00dcberschrift 6',
	'Heading 3': '\u00dcberschrift 3',
	'Decrease indent': 'Einzug verkleinern',
	'Header 4': '\u00dcberschrift 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Einf\u00fcgen ist nun im einfachen Textmodus. Inhalte werden ab jetzt als unformatierter Text eingef\u00fcgt, bis Sie diese Einstellung wieder ausschalten!',
	'Underline': 'Unterstrichen',
	'Cancel': 'Abbrechen',
	'Justify': 'Blocksatz',
	'Inline': 'Zeichenformate',
	'Copy': 'Kopieren',
	'Align left': 'Linksb\u00fcndig ausrichten',
	'Visual aids': 'Visuelle Hilfen',
	'Lower Greek': 'Griechische Kleinbuchstaben',
	'Square': 'Quadrat',
	'Default': 'Standard',
	'Lower Alpha': 'Kleinbuchstaben',
	'Circle': 'Kreis',
	'Disc': 'Punkt',
	'Upper Alpha': 'Gro\u00dfbuchstaben',
	'Upper Roman': 'R\u00f6mische Zahlen (Gro\u00dfbuchstaben)',
	'Lower Roman': 'R\u00f6mische Zahlen (Kleinbuchstaben)',
	'Name': 'Name',
	'Anchor': 'Textmarke',
	'You have unsaved changes are you sure you want to navigate away?':
		'Die \u00c4nderungen wurden noch nicht gespeichert, sind Sie sicher, dass Sie diese Seite verlassen wollen?',
	'Restore last draft': 'Letzten Entwurf wiederherstellen',
	'Special character': 'Sonderzeichen',
	'Source code': 'Quelltext',
	'Color': 'Farbe',
	'Right to left': 'Von rechts nach links',
	'Left to right': 'Von links nach rechts',
	'Emoticons': 'Emoticons',
	'Robots': 'Robots',
	'Document properties': 'Dokumenteigenschaften',
	'Title': 'Titel',
	'Keywords': 'Sch\u00fcsselw\u00f6rter',
	'Encoding': 'Zeichenkodierung',
	'Description': 'Beschreibung',
	'Author': 'Verfasser',
	'Fullscreen': 'Vollbild',
	'Horizontal line': 'Horizontale Linie',
	'Horizontal space': 'Horizontaler Abstand',
	'Insert/edit image': 'Bild einf\u00fcgen/bearbeiten',
	'General': 'Allgemein',
	'Advanced': 'Erweitert',
	'Source': 'Quelle',
	'Border': 'Rahmen',
	'Constrain proportions': 'Seitenverh\u00e4ltnis beibehalten',
	'Vertical space': 'Vertikaler Abstand',
	'Image description': 'Bildbeschreibung',
	'Style': 'Stil',
	'Dimensions': 'Abmessungen',
	'Insert image': 'Bild einf\u00fcgen',
	'Insert date/time': 'Datum/Uhrzeit einf\u00fcgen ',
	'Remove link': 'Link entfernen',
	'Url': 'URL',
	'Text to display': 'Anzuzeigender Text',
	'Anchors': 'Textmarken',
	'Insert link': 'Link einf\u00fcgen',
	'New window': 'Neues Fenster',
	'None': 'Keine',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'Diese Adresse scheint ein externer Link zu sein. M\u00f6chten Sie das dazu ben\u00f6tigte "http://" voranstellen?',
	'Target': 'Ziel',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'Diese Adresse scheint eine E-Mail-Adresse zu sein. M\u00f6chten Sie das dazu ben\u00f6tigte "mailto:" voranstellen?',
	'Insert/edit link': 'Link einf\u00fcgen/bearbeiten',
	'Insert/edit video': 'Video einf\u00fcgen/bearbeiten',
	'Poster': 'Poster',
	'Alternative source': 'Alternative Quelle',
	'Paste your embed code below:':
		'F\u00fcgen Sie Ihren Einbettungscode hier ein:',
	'Insert video': 'Video einf\u00fcgen',
	'Embed': 'Einbetten',
	'Nonbreaking space': 'Gesch\u00fctztes Leerzeichen',
	'Page break': 'Seitenumbruch',
	'Paste as text': 'Als Text einf\u00fcgen',
	'Preview': 'Vorschau',
	'Print': 'Drucken',
	'Save': 'Speichern',
	'Could not find the specified string.':
		'Die Zeichenfolge wurde nicht gefunden.',
	'Replace': 'Ersetzen',
	'Next': 'Weiter',
	'Whole words': 'Nur ganze W\u00f6rter',
	'Find and replace': 'Suchen und ersetzen',
	'Replace with': 'Ersetzen durch',
	'Find': 'Suchen',
	'Replace all': 'Alles ersetzen',
	'Match case': 'Gro\u00df-/Kleinschreibung beachten',
	'Prev': 'Zur\u00fcck',
	'Spellcheck': 'Rechtschreibpr\u00fcfung',
	'Finish': 'Ende',
	'Ignore all': 'Alles Ignorieren',
	'Ignore': 'Ignorieren',
	'Add to Dictionary': 'Zum W\u00f6rterbuch hinzuf\u00fcgen',
	'Insert row before': 'Neue Zeile davor einf\u00fcgen ',
	'Rows': 'Zeilen',
	'Height': 'H\u00f6he',
	'Paste row after': 'Zeile danach einf\u00fcgen',
	'Alignment': 'Ausrichtung',
	'Border color': 'Rahmenfarbe',
	'Column group': 'Spaltengruppe',
	'Row': 'Zeile',
	'Insert column before': 'Neue Spalte davor einf\u00fcgen',
	'Split cell': 'Zelle aufteilen',
	'Cell padding': 'Zelleninnenabstand',
	'Cell spacing': 'Zellenabstand',
	'Row type': 'Zeilentyp',
	'Insert table': 'Tabelle einf\u00fcgen',
	'Body': 'Inhalt',
	'Caption': 'Beschriftung',
	'Footer': 'Fu\u00dfzeile',
	'Delete row': 'Zeile l\u00f6schen',
	'Paste row before': 'Zeile davor einf\u00fcgen',
	'Scope': 'G\u00fcltigkeitsbereich',
	'Delete table': 'Tabelle l\u00f6schen',
	'H Align': 'Horizontale Ausrichtung',
	'Top': 'Oben',
	'Header cell': 'Kopfzelle',
	'Column': 'Spalte',
	'Row group': 'Zeilengruppe',
	'Cell': 'Zelle',
	'Middle': 'Mitte',
	'Cell type': 'Zellentyp',
	'Copy row': 'Zeile kopieren',
	'Row properties': 'Zeileneigenschaften',
	'Table properties': 'Tabelleneigenschaften',
	'Bottom': 'Unten',
	'V Align': 'Vertikale Ausrichtung',
	'Header': 'Kopfzeile',
	'Right': 'Rechtsb\u00fcndig',
	'Insert column after': 'Neue Spalte danach einf\u00fcgen',
	'Cols': 'Spalten',
	'Insert row after': 'Neue Zeile danach einf\u00fcgen',
	'Width': 'Breite',
	'Cell properties': 'Zelleneigenschaften',
	'Left': 'Linksb\u00fcndig',
	'Cut row': 'Zeile ausschneiden',
	'Delete column': 'Spalte l\u00f6schen',
	'Center': 'Zentriert',
	'Merge cells': 'Zellen verbinden',
	'Insert template': 'Vorlage einf\u00fcgen ',
	'Templates': 'Vorlagen',
	'Background color': 'Hintergrundfarbe',
	'Custom...': 'Benutzerdefiniert...',
	'Custom color': 'Benutzerdefinierte Farbe',
	'No color': 'Keine Farbe',
	'Text color': 'Textfarbe',
	'Show blocks': ' Bl\u00f6cke anzeigen',
	'Show invisible characters': 'Unsichtbare Zeichen anzeigen',
	'Words: {0}': 'W\u00f6rter: {0}',
	'Insert': 'Einf\u00fcgen',
	'File': 'Datei',
	'Edit': 'Bearbeiten',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Rich-Text- Area. Dr\u00fccken Sie ALT-F9 f\u00fcr das Men\u00fc. Dr\u00fccken Sie ALT-F10 f\u00fcr Symbolleiste. Dr\u00fccken Sie ALT-0 f\u00fcr Hilfe',
	'Tools': 'Werkzeuge',
	'View': 'Ansicht',
	'Table': 'Tabelle',
	'Format': 'Format',
});
